Crate mapvas

Crate mapvas 

Modules

command_line
Vim-like command line interface.
config
Contains the configuration for the application.
map
Contains the main map logic, including drawing, zooming,…
mapvas_ui
Contains the UI around the map.
parser
Parses different input to draw on the map.
profiling
Performance profiling utilities.
remote
Server logic to send data to a running application.
render_pool
Rayon thread pool for CPU-bound tile rendering.
search
Location search functionality with multiple providers.
task_tracker
Task tracking for UI display. Task tracking for displaying active tokio tasks

Macros

profile_function
Function-level profiling macro
profile_scope
Convenience macro for profiling scopes when profiling is enabled